<?php
/*
 * the login page
 */
require_once("include.php");

// button to login with account check etc.
class ButtonLogin extends InputPageButtonOnlyAction {
    public function ButtonLogin($name, $label) {
        parent::__construct($name, $label);
        //$this->anyway = true;
        $this->disabled = true; // must be enabled via javascript
    }
    
    function action(InputPage &$page, $phase) {
        $name = $page->getField("name");
        $password = $page->getField("password");
        $result = ReportingMethods::checkAccount($name->value, ReportingMethods::getMd5Pw($name->value, $password->value), "password");
        if ($result != false && $row = pg_fetch_object($result)) {
            global $reportingSession;
            $stayloggedin = $page->getField("stayloggedin");    // does the user likes to stay logged in?
            if($stayloggedin->get("on")) {  // yes, so set the cookies
                LoginCheck::updateCookies($row->name, $row->id);
            }
            // always set the session
            $reportingSession->sessionLoggedIn = true;
            $reportingSession->mainSession->save($reportingSession->sessionLoggedIn, "loggedin");
            $reportingUser = ReportingMethods::getUserFromRow($row);
            $reportingSession->updateUser($reportingUser);
            require 'report.php';
            exit;
        } else {
            $this->reRenderPage($page, tl::tl("No user with this name password combination found."));
        }
    }
    
    function reRenderPage(InputPage &$page, $error) {
        // reset password field (although it stays in the url)
        $tmp = $page->getField("password");
        $tmp->value = "";
        $this->msg = $error;
        $page->render();
    }
}

// main login page
class PageLogin extends MyPage {
    public function createFields() {
        $this->addSection("text");
        $this->currentSection = "text";
        $error = "";
        $tmp = $this->addField(new InputPageText("text", ""));
        if($error != "" || isset($_GET["error"])) {
            // error string, which is set before rerendering the page, therefor $error is set after adding field...
            if(isset($_GET["error"])) {
                $error = $_GET["error"];
            }
            $tmp->value = $error;
            $tmp->attributes["style"] = "color: red";
        }
        else {
            $tmp->autorender = false;
        }
        $javaHint = $this->addField(new InputPageText("nojavascript", ""));
        $javaHint->value = "<noscript><div style='color:red'><b>".tl::tl("Your browser does not support javascript or javascript is disabled.");
        $javaHint->value .= "<br>".tl::tl("This site can be used only with javascript.");
        $javaHint->value .= "</b></div></noscript>";
        $nameField = $this->addField(new InputPageStringField("name", tl::tl("Name")));
        
        $pwField = $this->addField(new InputPagePasswordField("password", tl::tl("Password")));
        $pwField->hint = tl::tl("Enter the password of your account.");
        
        $chkField = $this->addField(new InputPageCheckboxField("stayloggedin", tl::tl("Do you want to stay logged in on this pc?")));
        $chkField->hint = tl::tl("Check this to stay logged in on your pc until you log out.");
        
        $btn = $this->addField(new ButtonLogin("buttonlogin", tl::tl("Login")));
        $btn->setJavaScriptInit("function JavaScriptInit_{$btn->name}() { document.getElementsByName('{$btn->name}')[0].disabled = false; }");
        
        $pwField->attributes["onKeyDown"] = $chkField->attributes["onKeyDown"] = $nameField->attributes["onKeyDown"] = "javascript:submitButton(event, '{$btn->name}')";
    }
}

// includes the login fields and links for help/register
final class ReportingLogin extends ReportingInputPage {
    // constructor
    public function ReportingLogin() {
        parent::ReportingInputPage(tl::tl("Reporting Login"), "reportinglogin", false);
        $this->setFieldSectionAttributes("inline", new _InputPageFieldSectionAttributes(array(), 1));
        
        // add proper fields to pages
        $this->pages = array(ReportingLoginConsts::pageLogin => new PageLogin($this, false));
        
        $this->pages[$this->pageNo]->updateTitle();

        $this->pages[$this->pageNo]->createFields();
        
        $this->setDefaultTabProperties();
    }
};

// create page
InputPage::$method = "post";
$page = new ReportingLogin();
$page->work();
?>